//******************************************************************************
//
//                              PIC TWEET
//
//******************************************************************************
//  FileName:           pic_tweet.c
//  Company:            ENTESLA
//  website:            www.entesla.com
//  email:              feedbackATenteslaDOTcom
//  About:              This code pulls the latest tweets from your twitter account
//                      regularly, compares it with your last tweet and sends the
//                      tweet to serial port. This code was compiled under windows 7
//                      32-bit and was tested with PIC KICK development board from
//                      www.entesla.com. 
//                      Thanks to www.robotgrrl.com, twitter4j library and 
//                      processing.org.
//
//  Author              Date            Comment
//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
//  WebWarrior          12/12/10        Original
//******************************************************************************

//ADD twitter4j.jar to library/sketchbook

import processing.serial.*;  //import serial library

import twitter4j.conf.*;
import twitter4j.internal.async.*;
import twitter4j.internal.org.json.*;
import twitter4j.internal.logging.*;
import twitter4j.json.*;
import twitter4j.internal.util.*;
import twitter4j.management.*;
import twitter4j.auth.*;
import twitter4j.api.*;
import twitter4j.util.*;
import twitter4j.internal.http.*;
import twitter4j.*;
import twitter4j.internal.json.*;


//Fill the below variables with the OAUTH Keys from your twitter account
//These are the keys used to login to twitter account
static String OAuthConsumerKey = " ";
static String OAuthConsumerSecret = " ";
static String AccessToken = " ";
static String AccessTokenSecret = " ";

Serial myPort;  // Create object from Serial class
Twitter twitter = new TwitterFactory().getInstance();  //create instance

void setup() 
{
  size(700, 250);  //Size of the window
  frameRate(10);  //Frame rate  
  background(255);
  
  //Display Text in  window
  PFont font;  
  font = loadFont("ErasITC-Light-15.vlw"); //Load font from font folder
  textFont(font);                          //Set current font
  fill(100, 100, 100);                     //Set color of the font
  text("www.entesla.com", 579, 240);       //Display Text at location x,y
  //fill(90, 121, 121, 100);
  //text("@ENTESLA", 290, 30);
  
  //Display Image in window
  PImage b,a;
  b = loadImage("twitter-image.jpg");    //Load the twitter pic kick image
  image(b, 30, 5);                       //Display image(b) at location x,y 
  a  =  loadImage("store_logo.png");     //Load the image entesla store logo
  image(a, 578, 190);                    //Display the image(a) at location x,y
  
  // List all the available serial ports:
  //String portName = Serial.list()[0];
  //println(portName);                        //Display this the the debug window
  myPort = new Serial(this, Serial.list()[0], 9600);//Select the first COM port from the list
                                                    //Ensure the device is attached to COM1 
                                                    //Change the device port to COM1 from device manager
  
  loginTwitter();                                  //Login to Twitter
  loop();                                          //Loop the code within draw()
}



//Variable declaration
String msgOut = "updated";
String tempTweet="k";
String lastTweet="";
int i=1;


void draw() 
{
    //Retrieve Last Tweet
    lastTweet=readMsg(1);
    
    //Compare it with last tweet
    if(tempTweet.equals(lastTweet)==false)  
    {
      tempTweet=lastTweet;
      //Write to console
      println(lastTweet);  //for debugging
      //Write to Serial port      
      myPort.write(lastTweet);  //Send the string to serial port 
      //postMsg(msgOut);    
    }
    else
    {
  
    }
    delay(20000);  //Refresh every 20 seconds
}

//Twitter Login
void loginTwitter() 
{
  twitter.setOAuthConsumer(OAuthConsumerKey, OAuthConsumerSecret);
  AccessToken accessToken = loadAccessToken();
  twitter.setOAuthAccessToken(accessToken);
}

//Load Access Token
private static AccessToken loadAccessToken() 
{
  return new AccessToken(AccessToken, AccessTokenSecret);
}

//Post messages to Twitter
void postMsg(String s) 
{
  try 
  {
    Status status = twitter.updateStatus(s);
    println("new tweet --:{ " + status.getText() + " }:--");
  }
  catch(TwitterException e) 
  {
    println("Status Error: " + e + "; statusCode: " + e.getStatusCode());
  }
}

//Read messages from Twitter
String readMsg(int check)
{
  java.util.List statuses = null;
  String prevMsg="";
  if(check==1)
  {
    try
    {
      statuses = twitter.getUserTimeline();
    }
    catch (TwitterException e)
    {
      println("Timeline Error: "+e+";statusCode:"+e.getStatusCode());
    }
  Status status = (Status)statuses.get(0);
  prevMsg=status.getText();
  return prevMsg;
 }
 else
 {
   return prevMsg;
 }
}



